==> haskell-regex-posix-0.95.2-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-posix
version: 0.95.2
id: regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR
key: regex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR
license: BSD3
copyright: Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://code.haskell.org/regex-posix/
synopsis: Replaces/Enhances Text.Regex
description:
    The posix regex backend for regex-base
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.Wrap Text.Regex.Posix.String
    Text.Regex.Posix.Sequence Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy
abi: ed3320d29ccd34c7e9e7e3a384998beb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-posix-0.95.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-posix-0.95.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-posix-0.95.2
hs-libraries: HSregex-posix-0.95.2-Fy6xYMm8dnjHHt23b8RdmR
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
haddock-interfaces: /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html: /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-posix-0.95.2-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-posix
version: 0.95.2
id: regex-posix-0.95.2-KQJt29lnRa45d6bFn9XkFO
key: regex-posix-0.95.2-KQJt29lnRa45d6bFn9XkFO
license: BSD3
copyright: Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://code.haskell.org/regex-posix/
synopsis: Replaces/Enhances Text.Regex
description:
    The posix regex backend for regex-base
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.Wrap Text.Regex.Posix.String
    Text.Regex.Posix.Sequence Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy
abi: 1fc3d9fd23dcbaf4a9d4b523ff5b84bb
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/regex-posix-0.95.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/regex-posix-0.95.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/regex-posix-0.95.2
hs-libraries: HSregex-posix-0.95.2-KQJt29lnRa45d6bFn9XkFO
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    regex-base-0.93.2-AYjYAsBidAc8f5XNm9b2Aa
haddock-interfaces: /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html: /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
